@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use utf8;
 
-our $VERSION = '1.00';
+our $VERSION = '1.01';
 use Search::Fulltext::SQLite;
 
 sub new {
@@ -45,7 +45,6 @@ Search::Fulltext - Fulltext search module
 
     use Search::Fulltext;
     
-    my $query = 'beer';
     my @docs = (
         'I like beer the best',
         'Wine makes people saticefied',  # does not include beer
@@ -55,21 +54,23 @@ Search::Fulltext - Fulltext search module
     my $fts = Search::Fulltext->new({
         docs => \@docs,
     });
-    my $results = $fts->search($query);
+    my $results = $fts->search('beer');
     is_deeply($results, [0, 2]);         # 1st & 3rd doc include 'beer'
+    my $results = $fts->search('beer AND happy');
+    is_deeply($results, [2]);            # 3rd doc includes both 'beer' & 'happy'
 
 =head1 DESCRIPTION
 
 L<Search::Fulltext> is a fulltext search module. It can be used in a few steps.
 
 L<Search::Fulltext> has B<pluggable tokenizer> feature, which possibly provides fulltext search for any language.
-Currently, English and Japanese fulltext search are officially supported,
+Currently, B<English> and B<Japanese> fulltext search are officially supported,
 although any other languages which have spaces for separating words could be also used.
-See L</"CUSTOM TOKENIZERS"> section to learn how to search non-English languages.
+See L</CUSTOM TOKENIZERS|CUSTOM_TOKENIZERS> section to learn how to search non-English languages.
 
 B<SQLite>'s B<FTS4> is used as an indexer.
 Various queries supported by FTS4 (C<AND>, C<OR>, C<NEAR>, ...) are fully provided.
-See L<< Search::Fulltext->search >> section for types of queries.
+See L</QUERIES> section for details.
 
 =head1 METHODS
 
@@ -92,13 +93,13 @@ File path to write fulltext index. By default, on-memory index is used.
 =item C<@param tokenizer> B<[optional]>
 
 Tokenizer name to use. C<simple> (default) and C<porter> must be supported.
-C<icu> and C<unicode61> could be used if your SQLite libarary used via C<DBD::SQLite> module support them.
+C<icu> and C<unicode61> could be used if your SQLite libarary used via L<DBD::SQLite> module support them.
 See L<http://www.sqlite.org/fts3.html#tokenizer> for more details on FTS4 tokenizers.
 
 Japanese tokenizer C<perl 'Search::Fulltext::Tokenizer::MeCab::tokenizer'> is also available after you install
-L<Search::Fulltext::Tokenizer> module.
+L<Search::Fulltext::Tokenizer::MeCab> module.
 
-See L</"CUSTOM TOKENIZERS"> section for developing other tokenizers.
+See L</CUSTOM TOKENIZERS|CUSTOM_TOKENIZERS> section for developing other tokenizers.
 
 =back
 
@@ -119,6 +120,14 @@ Array of indexes of C<docs> passed through C<< Search::Fulltext->new >> in which
 =item C<@param query>
 
 Query to search from documents.
+See L</QUERIES> section for types of queries.
+
+=back
+
+=cut
+
+=head1 QUERIES
+
 The simplest query would be a term.
 
     my $results = $fts->search('beer');
@@ -133,18 +142,17 @@ Other queries below and combination of them can be also used.
     my $results = $fts->search('beer NEAR happy');
     my $results = $fts->search('beer NEAR/1 happy');
 
-See L<http://www.sqlite.org/fts3.html#section_3> for detail.
+See L<http://www.sqlite.org/fts3.html#section_3> for an explanation of each type of query.
 
-=back
-
-=cut
+B<NOTE:> Some custom tokenizers might not support full of these queries above.
+Check the document of each tokenizer before using complex queries.
 
 =head1 CUSTOM TOKENIZERS
 
-Custom tokenizers can be implemented by pure perl thanks to L<DBD::SQLite/"Perl tokenizers">.
+Custom tokenizers can be implemented by pure perl thanks to L<DBD::SQLite/Perl_tokenizers>.
 L<Search::Fulltext::Tokenizer::MeCab> is an example of custom tokenizers.
 
-See L<DBD::SQLite/"Perl tokenizers"> and L<Search::Fulltext::Tokenizer::MeCab> module to learn how to develop custom tokenizers.
+See L<DBD::SQLite/Perl_tokenizers> and L<Search::Fulltext::Tokenizer::MeCab> module to learn how to develop custom tokenizers.
 
 =head1 SUPPORTS
 
@@ -152,7 +160,7 @@ Bug reports and pull requests are welcome at L<https://github.com/laysakura/Sear
 
 =head1 VERSION
 
-Version 1.00
+Version 1.01
 
 =head1 AUTHOR
 
